<?php
/** 
 * The admin-specific functionality of the plugin.
 *
 * @link       https://https://codecanyon.net/search/kamleshyadav
 * @since      1.0.0
 *
 * @package    Image_Buzz
 * @subpackage Image_Buzz/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Image_Buzz
 * @subpackage Image_Buzz/admin
 * @author     kamleshyadav <admin@pixelnx.com>
 */
class Image_Buzz_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		
		add_shortcode( 'vid_image_buzz', array( $this,'image_buzz_img_generator' ) );

	}
	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Image_Buzz_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Image_Buzz_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
        wp_enqueue_style('toastr', plugin_dir_url( __FILE__ ) .'css/toastr.min.css', array(), $this->version, 'all');
        wp_enqueue_style($this->plugin_name, plugin_dir_url( __FILE__ ) .'css/image-buzz-admin.css', array(), $this->version, 'all');
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {
        /**
    	 * This function is provided for demonstration purposes only.
    	 *
    	 * An instance of this class should be passed to the run() function
    	 * defined in Image_Buzz_Loader as all of the hooks are defined
    	 * in that particular class.
    	 *
    	 * The Image_Buzz_Loader will then create the relationship
    	 * between the defined hooks and the functions defined in this
    	 * class.
    	 */ 
		wp_enqueue_media();
		wp_enqueue_script('toastr', plugin_dir_url( __FILE__ ).'js/toastr.min.js', array('jquery'), $this->version, false);
        wp_enqueue_script($this->plugin_name, plugin_dir_url( __FILE__ ).'js/image-buzz-admin.js', array('jquery'), $this->version, false);
        wp_localize_script($this->plugin_name, 'image_buzz_ajax_path', array(
			'url' => admin_url('admin-ajax.php'),
			) 
	    );
	}
	
	/**
	 * Image Buzz Dashboard Menu Option
	 */
    public function image_buzz_admin_menus(){
    	/**
    	 * Dashboard Menu
    	 */
    	add_menu_page( 
    		esc_html__('Image Buzz','image-buzz'),
    		esc_html__('Image Buzz','image-buzz'),
    		'manage_options',
    		'image-buzz-setting',
    		 array($this, 'image_buzz_setting_option'),
    		'dashicons-format-gallery',
    		6
      	  );
		/**
		 * Image Buzz Setting Youtube
		 */
	    add_submenu_page('image-buzz-setting', 
			esc_html__('Image Buzz Youtube','image-buzz'), 
			esc_html__('Image Buzz Youtube','image-buzz'), 
			'manage_options', 
			'image-buzz-youtube', 
			array($this, 'image_buzz_youtube_setting')
	      ); 
		
	}
	/**
	 * Image Buzz Setting Option
	 */ 
	 public function image_buzz_setting_option(){
	    require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/image-buzz-admin-display.php';
	 }
	 
	 /**
	 * image buzz youtube setting
	 */ 
	 public function image_buzz_youtube_setting(){
		$youtube_api ='';
        $youtube_api = get_option('imagebuzz_youtube_api_save');
		
		    $yt_video_id = '';
			if(!empty($_GET['vid'])):
			    $yt_video_id = sanitize_text_field($_GET['vid']);
                $json = wp_remote_get('https://www.googleapis.com/youtube/v3/videos?id='.$yt_video_id.'&key='.$youtube_api.'&part=snippet');
                $ytdata = json_decode($json['body'],true);
				$curl = curl_init(); 
			    curl_setopt_array($curl, array(
					CURLOPT_URL => 'https://ajaxcontact.node.pixelnx.com/caption/'.$yt_video_id,
					CURLOPT_RETURNTRANSFER => true,
					CURLOPT_ENCODING => '',
					CURLOPT_MAXREDIRS => 10,
					CURLOPT_TIMEOUT => 0,
					CURLOPT_FOLLOWLOCATION => true,
					CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
					CURLOPT_CUSTOMREQUEST => 'POST',
			     ));
			  $response = curl_exec($curl);
			  curl_close($curl);
			  $resdata = json_decode($response,true);
			  $textcontent = '';
			  if(!empty($resdata)):
				foreach($resdata as $data):
					if(isset($data['text'])):
					  $textcontent .= $data['text'];
                    endif;
				endforeach;
			  endif;
                require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/image-buzz-admin-create-post.php';
			  else:
				$lang = esc_html__('en','image-buzz');
				$keyword_arr = array('motivational','social','yoga','ai','religation','meditation','business','share market','miraculous','war','weapons');
	            shuffle($keyword_arr);
				$search_keyword = esc_html($keyword_arr[0]);
				$feed_url = 'https://www.googleapis.com/youtube/v3/search?relevanceLanguage='.$lang .'&chart=mostPopular&videoEmbeddable=true&videoCaption=closedCaption&part=snippet&type=video&q='.urlencode($search_keyword).'&key='.$youtube_api; 
                $jsondata = wp_remote_get($feed_url);
				$ytdata = json_decode($jsondata['body'],true);
				require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/image-buzz-admin-youtube-post.php';
			endif;
	 }
	 /**
	 * image buzz  Videos Filter 
	 */ 
	public function image_buzz_videos_filters(){
		//$youtube_api = get_option('ytc_youtube_api');
	    $youtube_api ='';
        $youtube_api = get_option('imagebuzz_youtube_api_save');
		$lang = '';
		if(isset($_POST['search_languach'])):
			$lang = sanitize_text_field($_POST['search_languach']);
		endif;
		$search_keyword = '';
		if(isset($_POST['search_key_words'])):
			$search_keyword = sanitize_text_field($_POST['search_key_words']);
		endif;
	    $feed_url = 'https://www.googleapis.com/youtube/v3/search?relevanceLanguage='.$lang.'&chart=mostPopular&videoEmbeddable=true&videoCaption=closedCaption&part=snippet&type=video&q='.urlencode($search_keyword) .'&key='.$youtube_api;
		$json = wp_remote_get($feed_url);
        $ytdata = json_decode($json['body'],true);
		if(!empty($ytdata['items'])):
			foreach($ytdata['items'] as $postvideo_list):
			if(!empty($postvideo_list['snippet']['title'])):
				$JSON = wp_remote_get("https://www.googleapis.com/youtube/v3/videos?part=statistics&id=" . $postvideo_list['id']['videoId']. "&key=".$youtube_api);
				$JSON_Data = json_decode($JSON['body'],true);
		?> 
		<div class="ytc-thumb-box">
			<?php if(isset($postvideo_list['snippet']['thumbnails']['default']['url'])): ?>
			<div class="ytc-thumb-video"> 
				<a href="javascript:void(0);" open-modal="videoModal" class="ytc-modal-link">
					<img src="<?php echo esc_url($postvideo_list['snippet']['thumbnails']['default']['url']); ?>" alt="<?php echo esc_attr($postvideo_list['snippet']['title']); ?>"> 
					<span class="ytc-hover-icon" data-videourl="<?php echo esc_url('https://www.youtube.com/embed/'.esc_attr($postvideo_list['id']['videoId'])); ?>"> 
					<svg xmlns="http://www.w3.org/2000/svg" version="1.1" xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:svgjs="http://svgjs.com/svgjs" x="0" y="0" viewBox="0 0 512 512" xml:space="preserve"><g><path d="m484.102 263.836 4.8-7.836-4.8-7.84c-.805-1.308-20.118-32.48-57.637-63.719-49.903-41.543-108.692-63.504-170.016-63.504-61.308 0-120.242 21.95-170.43 63.473-37.734 31.223-57.265 62.371-58.078 63.684L23.04 256l4.902 7.906c.813 1.313 20.344 32.461 58.079 63.684 50.187 41.523 109.12 63.472 170.43 63.472 61.323 0 120.112-21.96 170.015-63.503 37.52-31.239 56.832-62.41 57.637-63.723zm-77.63 41.324c-44.89 37.094-95.367 55.899-150.023 55.899-54.676 0-105.316-18.817-150.511-55.934C82.563 285.93 66.715 266.492 58.953 256c7.766-10.5 23.613-29.934 46.985-49.129 45.195-37.113 95.832-55.934 150.511-55.934 54.656 0 105.13 18.81 150.024 55.899 23.27 19.226 38.98 38.691 46.636 49.164-7.664 10.477-23.37 29.941-46.636 49.16zm0 0" fill="currentColor" /><path d="M256 165.867c-49.7 0-90.133 40.434-90.133 90.133s40.434 90.133 90.133 90.133 90.133-40.434 90.133-90.133-40.434-90.133-90.133-90.133zm0 150.266c-33.156 0-60.133-26.977-60.133-60.133s26.977-60.133 60.133-60.133 60.133 26.977 60.133 60.133-26.977 60.133-60.133 60.133zM30 30h62.625V0H0v91.5h30zM419.375 0v30H482v61.5h30V0zM30 420.5H0V512h92.625v-30H30zM482 482h-62.625v30H512v-91.5h-30zm0 0" fill="currentColor" /></g></svg>
					</span>
				</a>
		    </div>
		<?php endif; ?>
		<div class="ytc-thumb-content">
			<?php if(!empty($postvideo_list['snippet']['title'])): ?>
			<h4><?php echo esc_html($postvideo_list['snippet']['title']); ?></h4>
			<?php endif; ?>
			<?php if(isset($JSON_Data['items'][0]['statistics']['likeCount'])): ?>
			<ul class="yt-post-info">
				<li>
				<span>
				 <img src="<?php echo esc_url(plugins_url('image-buzz/admin/images/like.svg')); ?>" alt="<?php echo esc_attr__('Likes','image-buzz'); ?>" />
				</span>
				<?php if(isset($JSON_Data['items'][0]['statistics']['likeCount'])): ?>
				<?php 
				echo image_buzz_format_number($JSON_Data['items'][0]['statistics']['likeCount']); 
				echo esc_html__(' Likes','image-buzz');  
				?> 
				</li>
				<li>
				<span>
				<img src="<?php echo esc_url(plugins_url( 'image-buzz/admin/images/views.svg')); ?>" alt="<?php echo esc_attr__('Views','image-buzz'); ?>" />
				</span> 
				<?php endif;
				if(isset($JSON_Data['items'][0]['statistics']['viewCount'])):
				?>
				<?php echo image_buzz_format_number($JSON_Data['items'][0]['statistics']['viewCount']); ?> <?php echo esc_html__('Views','image-buzz'); ?>
				<?php endif; ?>
				</li>
			</ul>
			<?php 
			endif;
			if(isset($postvideo_list['id']['videoId'])): ?>
			<div class="ytc-thumb-btn">
				<a href="<?php echo admin_url('admin.php?page=image-buzz-youtube&vid='.esc_attr($postvideo_list['id']['videoId'])); ?>" class="ytc-btn">
					<?php echo esc_html__('Create Post','image-buzz'); ?>
				</a>
			</div>
			<?php endif; ?>
		  </div>
	    </div>
	   <?php  
	   endif;
	  endforeach;
	 else:
		if(isset($ytdata['error']['message'])):
			echo "<h1>".wp_kses($ytdata['error']['message'],true)."</h1>";
		else:
			echo "<h1>".esc_html__('Search result is not found!','image-buzz')."</h1>";
		endif;
	 endif; 
	wp_die();	
	}
	
	 
	/**
	 * WP Media Frame Add New Tab and data
	 */ 
	public function image_buzz_api_images(){
		$unsplash_api = get_option('imagebuzz_unsplash_api');
		$unsplash_active_tab = '';
		if(!empty($unsplash_api)):
		   $unsplash_active_tab = esc_html__('active','image-buzz');
		endif;
		$pixabay_api = get_option('imagebuzz_pixabay_api');
		$pixabay_active_tab = '';
		if(!empty($pixabay_api)):
		   $pixabay_active_tab = esc_html__('active','image-buzz');
		endif;
		$pexels_api = get_option('imagebuzz_pixels_api_save');
		$pexels_active_tab = '';
		if(!empty($pexels_api)):
		   $pexels_active_tab = esc_html__('active','image-buzz');
		endif;
        $imagebuzz_openai_api_save ='';
        $imagebuzz_openai_api_save = get_option('imagebuzz_openai_api_save');
        $openai_api = '';
		if(!empty($imagebuzz_openai_api_save)):
		   $openai_api = esc_html__('active','image-buzz');
		endif;
        $data_keys = ''; 
		if(!empty($_POST['data_keys'])):
		 $data_keys = sanitize_text_field($_POST['data_keys']);
        endif;  
		echo '<div class="imagebuzz-top-div">
			    <div class="imagebuzz-api-buttons">';
					if(!empty($unsplash_api)):
						echo '<a href="javascript:;" class="imagebuzz-btn imagebuzz_api_buttons '.esc_attr($unsplash_active_tab).'" id="imagebuzz-Unsplash" data-types="'.esc_attr('Unsplash', 'image-buzz').'" data-keys="'.esc_attr($data_keys).'">'.esc_html('Unsplash', 'image-buzz').'</a>';
					endif;
					if(!empty($pixabay_api)):
						echo '<a href="javascript:;" class="imagebuzz-btn imagebuzz_api_buttons '.esc_attr($pixabay_active_tab).'" id="imagebuzz-Pixabay" data-types="'.esc_attr('Pixabay', 'image-buzz').'" data-keys="'.esc_attr($data_keys).'">'.esc_html('Pixabay','image-buzz').'</a>';
					endif;
					if(!empty($pexels_api)):
						echo '<a href="javascript:;" class="imagebuzz-btn imagebuzz_api_buttons '.esc_attr($pexels_active_tab).'" id="imagebuzz-Pexels" data-types="'.esc_attr('Pexels', 'image-buzz').'" data-keys="'.esc_attr($data_keys).'">'.esc_html('Pexels', 'image-buzz').'</a>';
					endif;
					if(!empty($imagebuzz_openai_api_save)):
						echo '<a href="javascript:;" class="imagebuzz-btn imagebuzz_api_buttons '.esc_attr($pexels_active_tab).'" id="imagebuzz-openai" data-types="'.esc_attr('openai', 'image-buzz').'" data-keys="'.esc_attr($data_keys).'">'.esc_html('OpenAi', 'image-buzz').'</a>';
					endif;
			echo '</div>';
			if(!empty($unsplash_api) || !empty($pixabay_api) || !empty($pexels_api) || !empty($openai_api)):
				echo '<div class="imagebuzz-form-search-image">
					<input type="text" value="'.esc_attr__('car','image-buzz').'" class="imagebuzz-search-image" name="title" id="imagebuzz-search-images-name">
					<a href="javascript:;" class="imagebuzz-image-find-name imagebuzz-btn buzz-btn" data-type="'.esc_attr('Unsplash', 'image-buzz').'">'.esc_html__('Find Image','image-buzz').'</a>
				</div>';
			endif;
		echo '</div>
		<div class="imagebuzz-bottom-div">
			<div class="imagebuzz-media-images">
				<div class="imagebuzz-media-images-ajax row">';
					if(!empty($unsplash_api)){
						$key = str_replace(" ","-",$data_keys);
						$surl = "https://api.unsplash.com/search/photos?query=$key&per_page=30&client_id=$unsplash_api";
						$curl = curl_init($surl);
						curl_setopt($curl, CURLOPT_URL, $surl);
						curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
						curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, false);
						curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
						$resp = curl_exec($curl);
						curl_close($curl); 
						$images = json_decode($resp);
						if(!empty($images)){
							foreach($images->results as $image){
								$array = explode('?', $image->urls->regular);
							    
							?>
							<div class="buzz-thumb-box">
								<img src="<?php echo esc_url($image->urls->thumb); ?>" class="img-fluid">
								<div class="imagebuzz-action">
								    <a href="javascript:void(0)" data-url="<?php echo base64_encode(esc_url($image->urls->regular)); ?>" data-id="<?php echo esc_attr($image->id); ?>" class="imagebuzz-savemedia-image">
									   <?php echo esc_html__('Use','image-buzz'); ?> 
								    </a>
								</div>
							</div>
							<?php
							}
						}
					} else if(empty($unsplash_api) && !empty($pixabay_api)){
						$curl = curl_init();
						curl_setopt_array($curl, array(
							CURLOPT_URL => 'https://pixabay.com/api/?key='.$pixabay_api.'&per_page=30&page='.$data_page.'&q='.$data_keys.'&image_type=photo&pretty=true',
							CURLOPT_RETURNTRANSFER => true,
							CURLOPT_ENCODING => '',
							CURLOPT_MAXREDIRS => 10,
							CURLOPT_TIMEOUT => 0,
							CURLOPT_FOLLOWLOCATION => true,
							CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
							CURLOPT_CUSTOMREQUEST => 'GET',
							CURLOPT_HTTPHEADER => array(
								'Cookie: __cf_bm=t_ohWeKgkH4JjLxi9PbP_Y9c7TgDZ2cZQ7x72WTwgJk-1652880378-0-AYTXyVFddP/BL7+WvNr0xdFz8BEq6X6igjQmdUN41fHPQXwciAVBZ5iji+BL5ooxEQea0TjQ0J7BRE3XoK1eUOs=; anonymous_user_id=None; csrftoken=uzqhvnvqO6Icn30sibL3jiLz2atJJEAB3kgmZSt060mLQjmOC1xPGK0AvwVzH56X'
							),
						));
						$response = curl_exec($curl);
						curl_close($curl);
						$pixabay = json_decode($response);
						if(!empty($pixabay)){
							foreach($pixabay->hits as $pixabay_images){
							?>
							<div class="buzz-thumb-box">
								<img src="<?php echo esc_url($pixabay_images->previewURL); ?>" class="img-fluid">
								<div class="imagebuzz-action">
									<a href="javascript:;" data-url="<?php echo base64_encode(esc_url($pixabay_images->largeImageURL)); ?>" data-id="<?php echo esc_attr($pixabay_images->id); ?>" class="imagebuzz-savemedia-image">
                                      <?php echo esc_html__('Use','image-buzz'); ?> 
								    </a>
							    </div>
							</div>
							<?php
							}
						}
					} else if(empty($unsplash_api) && empty($pixabay_api) && !empty($pexels_api)){
						$key = str_replace(" ","%20",$data_keys);
						$url = 'https://api.pexels.com/v1/search?query='.$key.'&per_page=30&page='.$data_page;
						$curl = curl_init();
						curl_setopt_array($curl, array(
							CURLOPT_URL => $url,
							CURLOPT_RETURNTRANSFER => true,
							CURLOPT_ENCODING => '',
							CURLOPT_MAXREDIRS => 10,
							CURLOPT_TIMEOUT => 0,
							CURLOPT_FOLLOWLOCATION => true,
							CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
							CURLOPT_CUSTOMREQUEST => 'GET',
							CURLOPT_HTTPHEADER => array(
							'api_key: '.$pexels_api,
							'Authorization: Bearer '.$pexels_api,
							'Cookie: __cf_bm=4JYY2vcuQKDMvsNKKSdAQRMCPPi1ri55a_snlqkWb8U-1652953710-0-AUybkRsqWadcSmPxGeWQwvMqkCDNHk9cz+h35TRgXVHjua2TpHvM/UWSMjyDBkeF/T+XGDu4O1szeHwTWSu878U='
							),
						));
						$pexels_res = curl_exec($curl);
						curl_close($curl);
						$pexels = json_decode($pexels_res);
						if(!empty($pexels)){
							foreach($pexels->photos as $pexels_images){
							    $array = explode('?', $pexels_images->src->large);
							?>
							<div class="buzz-thumb-box">
								<img src="<?php echo esc_url($pexels_images->src->small); ?>" class="img-fluid">
								<div class="imagebuzz-action">
									<a href="javascript:;" data-url="<?php echo base64_encode(esc_url($array[0])); ?>" data-id="<?php echo esc_attr($pexels_images->id); ?>" class="imagebuzz-savemedia-image">
									   <?php echo esc_html__('Use','image-buzz'); ?> 
									</a>
								</div>
							</div>
							<?php
							}
						}
					}else if(empty($unsplash_api) && empty($pixabay_api) && empty($pexels_api)&& !empty($imagebuzz_openai_api_save)){
						
						$url = 'https://api.pexels.com/v1/search?query='.$key.'&per_page=30&page='.$data_page;
						$ogj = str_replace(" ","%20",$data_keys);
                		if(!empty($_POST['size'])){
                		    $size = $_POST['size'];
                		}else{
                		    $size = "1024x1024";
                		}
                		ob_start();
                		if(!empty($ogj)){
                    		    
                    		$args = array(
                                "prompt" => $ogj,
                                "n"=>10,
                                "size"=>$size
                            );                                                      
                            
        	            	$imagebuzz_openai_api_save = get_option('imagebuzz_openai_api_save');
                            $data_string = json_encode($args);  
                            $ch = curl_init('https://api.openai.com/v1/images/generations');
                            curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "POST");                                       
                            curl_setopt($ch, CURLOPT_POSTFIELDS, $data_string);
                            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);                         
                            curl_setopt($ch, CURLOPT_HTTPHEADER, array(
                            'Authorization: Bearer '.$imagebuzz_openai_api_save,
                            'Content-Type: application/json'
                            ));
                            $result = curl_exec($ch);
                            $a = json_decode($result,true);
                            if(isset($a['data'])){
                                foreach($a['data'] as $a_child){
                                    $imgUrl = $a_child['url'];
                                    echo '<div class="buzz-thumb-box">
                                        <img src="'.$imgUrl.'">
                                        <div class="imagebuzz-action">
                    					    <a href="javascript:void(0)" data-url="'.base64_encode($imgUrl).'" data-id="1111" class="imagebuzz-savemedia-image">
                    						   '. esc_html__('Use','image-buzz').' 
                    					    </a>
                    					</div>
                    				</div>';
                                }
                            }
                            else{
                                echo '<p>'.$a['error']['message'].'</p>';
                            }
                		}
                        else{
                            echo '<p>Please Enter Object Name.</p>';
                        }
                        wp_die();
					}
						
				echo '</div>'; 
				if(!empty($unsplash_api) || !empty($pixabay_api) || !empty($pexels_api) || !empty($imagebuzz_openai_api_save)){
					echo '<div id="imagebuzz-result-load" class="load-more-btn">
							<a href="javascript:;" id="imagebuzz-images-loadmore" data-images="20" data-page="1" data-types="'.esc_attr__('Unsplash', 'image-buzz').'" data-keys="'.esc_attr__('school','image-buzz').'" class="imagebuzz-btn buzz-btn">'.esc_html__('Load More', 'image-buzz').'</a>									
						</div>';
				}
				if(empty($unsplash_api) && empty($pixabay_api) && empty($pexels_api) && empty($imagebuzz_openai_api_save)){
					echo '<div class="No Found">
						<h3>'.esc_html__('Please Add At Least One API', 'image-buzz').'</h3>
					</div>';
				}
			echo '</div>
		</div>';
		wp_die();
	}
	
	/**
	 * WP Media Frame Add Data Action Perform Search, Load More, View
	 */
    public function image_buzz_button_images_load(){
	    $unsplash_api = get_option('imagebuzz_unsplash_api');
		$pixabay_api = get_option('imagebuzz_pixabay_api');
		$pexels_api = get_option('imagebuzz_pixels_api_save');
		$data_types = '';
		if(!empty($_POST['data_types'])):
		$data_types = sanitize_text_field($_POST['data_types']);
        endif;
		$data_keys = '';
		if(!empty($_POST['data_keys'])):
		$data_keys = sanitize_text_field($_POST['data_keys']);
        endif;
        $data_page_value = '';
		if(!empty($_POST['data_page'])):
		   $data_page_value = sanitize_text_field($_POST['data_page']);
		endif;
        $data_page = isset($data_page_value) ? intval($data_page_value) : ''; 
        if(empty($data_page)){
			$data_page = 1;
		} else {
			$data_page += 1;
		 }
		if(!empty($data_types) && !empty($data_keys)){
			if($data_types == 'Unsplash'){
				$key = str_replace(" ","-",$data_keys);
				$surl = "https://api.unsplash.com/search/photos?query=$key&page=$data_page&per_page=30&client_id=$unsplash_api";
				$curl = curl_init($surl);
				curl_setopt($curl, CURLOPT_URL, $surl);
				curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
				curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, false);
				curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
				$resp = curl_exec($curl);
				curl_close($curl);
				$images = json_decode($resp);
				if(!empty($images)){
					foreach($images->results as $image){
						$array = explode('?', $image->urls->regular);
						?>
						<div class="buzz-thumb-box">
							<img src="<?php echo esc_url($image->urls->thumb); ?>" class="img-fluid">
							<div class="imagebuzz-action">
								<a href="javascript:;" data-url="<?php echo base64_encode(esc_url($image->urls->regular)); ?>" data-id="<?php echo esc_attr($image->id); ?>" class="imagebuzz-savemedia-image">
								<?php echo esc_html__('Use','image-buzz'); ?>
								</a>
					        </div>
						</div>
						<?php
					}
				}	
			} elseif($data_types == 'Pixabay'){
				$curl = curl_init();
				curl_setopt_array($curl, array(
					CURLOPT_URL => 'https://pixabay.com/api/?key='.$pixabay_api.'&per_page=30&page='.$data_page.'&q='.$data_keys.'&image_type=photo&pretty=true',
					CURLOPT_RETURNTRANSFER => true,
					CURLOPT_ENCODING => '',
					CURLOPT_MAXREDIRS => 10,
					CURLOPT_TIMEOUT => 0,
					CURLOPT_FOLLOWLOCATION => true,
					CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
					CURLOPT_CUSTOMREQUEST => 'GET',
					CURLOPT_HTTPHEADER => array(
						'Cookie: __cf_bm=t_ohWeKgkH4JjLxi9PbP_Y9c7TgDZ2cZQ7x72WTwgJk-1652880378-0-AYTXyVFddP/BL7+WvNr0xdFz8BEq6X6igjQmdUN41fHPQXwciAVBZ5iji+BL5ooxEQea0TjQ0J7BRE3XoK1eUOs=; anonymous_user_id=None; csrftoken=uzqhvnvqO6Icn30sibL3jiLz2atJJEAB3kgmZSt060mLQjmOC1xPGK0AvwVzH56X'
					),
				));
				$response = curl_exec($curl);
				curl_close($curl);
				$pixabay = json_decode($response);
				if(!empty($pixabay)){
					foreach($pixabay->hits as $pixabay_images){
					?>
					<div class="buzz-thumb-box">
					    <img src="<?php echo esc_url($pixabay_images->previewURL); ?>" class="img-fluid">
						<div class="imagebuzz-action">
						    <a href="javascript:;" data-url="<?php echo base64_encode(esc_url($pixabay_images->largeImageURL)); ?>" data-id="<?php echo esc_attr($pixabay_images->id); ?>" class="imagebuzz-savemedia-image">
							  <?php echo esc_html__('Use','image-buzz'); ?>
							</a>
					    </div>
					</div> 
					<?php
					}
				}	
			} elseif($data_types == 'Pexels') {
				$key = str_replace(" ","%20",$data_keys);
				$url = 'https://api.pexels.com/v1/search?query='.$key.'&per_page=30&page='.$data_page;
				$curl = curl_init();
				curl_setopt_array($curl, array(
					CURLOPT_URL => $url,
					CURLOPT_RETURNTRANSFER => true,
					CURLOPT_ENCODING => '',
					CURLOPT_MAXREDIRS => 10,
					CURLOPT_TIMEOUT => 0,
					CURLOPT_FOLLOWLOCATION => true,
					CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
					CURLOPT_CUSTOMREQUEST => 'GET',
					CURLOPT_HTTPHEADER => array(
					'api_key: '.$pexels_api,
					'Authorization: Bearer '.$pexels_api,
					'Cookie: __cf_bm=4JYY2vcuQKDMvsNKKSdAQRMCPPi1ri55a_snlqkWb8U-1652953710-0-AUybkRsqWadcSmPxGeWQwvMqkCDNHk9cz+h35TRgXVHjua2TpHvM/UWSMjyDBkeF/T+XGDu4O1szeHwTWSu878U='
					),
				));
				$pexels_res = curl_exec($curl);
				curl_close($curl);
				$pexels = json_decode($pexels_res);
				if(!empty($pexels)){
					foreach($pexels->photos as $pexels_images){
					    $array = explode('?', $pexels_images->src->large);
				?>
				<div class="buzz-thumb-box">
				    <img src="<?php echo esc_url($pexels_images->src->small); ?>" class="img-fluid">
					<div class="imagebuzz-action">
					  <a href="javascript:;" data-url="<?php echo base64_encode(esc_url($array[0])); ?>" data-id="<?php echo esc_attr($pexels_images->id); ?>" class="imagebuzz-savemedia-image">
					   <?php echo esc_html__('Use','image-buzz'); ?>
				      </a>
					</div>
				</div>
				<?php
				 }
			  }
			}
			elseif($data_types == 'openai') {
			    $ogj = str_replace(" ","%20",$data_keys);
        		if(!empty($_POST['size'])){
        		    $size = $_POST['size'];
        		}else{
        		    $size = "1024x1024";
        		}
        		ob_start();
        		if(!empty($ogj)){
            		    
            		$args = array(
                        "prompt" => $ogj,
                        "n"=>10,
                        "size"=>$size
                    );                                                      
                    
	            	$imagebuzz_openai_api_save = get_option('imagebuzz_openai_api_save');
                    $data_string = json_encode($args);  
                    $ch = curl_init('https://api.openai.com/v1/images/generations');
                    curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "POST");                                       
                    curl_setopt($ch, CURLOPT_POSTFIELDS, $data_string);
                    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);                         
                    curl_setopt($ch, CURLOPT_HTTPHEADER, array(
                    'Authorization: Bearer '.$imagebuzz_openai_api_save,
                    'Content-Type: application/json'
                    ));
                    $result = curl_exec($ch);
                    $a = json_decode($result,true);
                    if(isset($a['data'])){
                        foreach($a['data'] as $a_child){
                            $imgUrl = $a_child['url'];
                            echo '<div class="buzz-thumb-box">
                                <img src="'.$imgUrl.'">
                                <div class="imagebuzz-action">
            					    <a href="javascript:void(0)" data-url="'.base64_encode($imgUrl).'" data-id="1111" class="imagebuzz-savemedia-image">
            						   '. esc_html__('Use','image-buzz').' 
            					    </a>
            					</div>
            				</div>';
                        }
                    }
                    else{
                        echo '<p>'.$a['error']['message'].'</p>';
                    }
        		}
                else{
                    echo '<p>Please Enter Object Name.</p>';
                }
                wp_die();
			}
		}
        wp_die();
	}

	/**
	 * Pixabay Api Save 
	 */ 
	public function image_buzz_pixabay_api_save(){
        extract($_POST);
	    if(update_option('imagebuzz_pixabay_api', $pixabay_api)){
            echo json_encode(array('status'=>true,'message'=>esc_html__("Pixabay Api Saved Successfully","image-buzz")));
		}else{
		    echo json_encode(array('status'=>false,'message'=>esc_html__("Something went to wrong!","image-buzz")));
		}
     wp_die();   
	} 
	 
	/**
	 * Unsplash Api Save 
	 */
	public function image_buzz_unsplash_api_save(){
        extract($_POST);
	    if(update_option('imagebuzz_unsplash_api', $unsplash_api)){
            echo json_encode(array('status'=>true,'message'=>esc_html__("Unsplash Api Saved Successfully","image-buzz")));
		}else{
			echo json_encode(array('status'=>false,'message'=>esc_html__("Something went to wrong!","image-buzz")));
		}
	 wp_die();   
	} 
	/**
	 * Pixels Api Save 
	 */ 
	public function image_buzz_pixels_api_save(){
		extract($_POST);
	    if(update_option('imagebuzz_pixels_api_save', $pixels_api)){
            echo json_encode(array('status'=>true,'message'=>esc_html__("Pixels Api Saved Successfully","image-buzz")));
		}else{
		   echo json_encode(array('status'=>false,'message'=>esc_html__("Something went to wrong!","image-buzz")));
		}
	 wp_die();   
	} 
	/**
	 * Pixels Api Save 
	 */ 
	public function image_buzz_openai_api_save(){
		extract($_POST);
	    if(update_option('imagebuzz_openai_api_save', $openai_api)){
            echo json_encode(array('status'=>true,'message'=>esc_html__("OpenAi Api Saved Successfully","image-buzz")));
		}else{
		   echo json_encode(array('status'=>false,'message'=>esc_html__("Something went to wrong!","image-buzz")));
		}
	 wp_die();   
	} 
	/**
	 * Youtube Api Save 
	 */ 
	public function imagebuzz_youtube_save(){
		extract($_POST);
	    if(update_option('imagebuzz_youtube_api_save', $openai_api)){
            echo json_encode(array('status'=>true,'message'=>esc_html__("Youtube Api Saved Successfully","image-buzz")));
		}else{
		   echo json_encode(array('status'=>false,'message'=>esc_html__("Something went to wrong!","image-buzz")));
		}
	 wp_die();   
	} 
	/**
	 * Image Buzz Api Clear
	 */
	public function image_buzz_api_clear(){
         extract($_POST); 
		 switch($clear_api_type){
           case'pixels_api':
				if(delete_option('imagebuzz_pixels_api_save')){
					echo json_encode(array('status'=>true,'message'=>esc_html__("Pixels Api Cleared Successfully","image-buzz")));
				}else{
					echo json_encode(array('status'=>false,'message'=>esc_html__("Something went to wrong!","image-buzz")));
				} 
		   break;
           case'unsplash_api':
				if(delete_option('imagebuzz_unsplash_api')){
					echo json_encode(array('status'=>true,'message'=>esc_html__("Unsplash Api Cleared Successfully","image-buzz")));
				}else{
					echo json_encode(array('status'=>false,'message'=>esc_html__("Something went to wrong!","image-buzz")));
				}
		   break;  
		   case'pixabay_api':
				if(delete_option('imagebuzz_pixabay_api')){
					echo json_encode(array('status'=>true,'message'=>esc_html__("Pixabay Api Cleared Successfully","image-buzz")));
				}else{
					echo json_encode(array('status'=>false,'message'=>esc_html__("Something went to wrong!","image-buzz")));
				}
		   break;
		   case'openai_api':
				if(delete_option('imagebuzz_openai_api_save')){
					echo json_encode(array('status'=>true,'message'=>esc_html__("Openai Api Cleared Successfully","image-buzz")));
				}else{
					echo json_encode(array('status'=>false,'message'=>esc_html__("Something went to wrong!","image-buzz")));
				}
		   break;
		   case'youtube_api':
				if(delete_option('imagebuzz_youtube_api_save')){
					echo json_encode(array('status'=>true,'message'=>esc_html__("Youtube Api Cleared Successfully","image-buzz")));
				}else{
					echo json_encode(array('status'=>false,'message'=>esc_html__("Something went to wrong!","image-buzz")));
				}
		   break;
		 }
     wp_die();
	}

	/**
	 * Images upload media
	 */ 
	public function image_buzz_upload_save_media(){
        $img_title = '';
		if(!empty($_POST['title'])):
		  $img_title = sanitize_text_field($_POST['title']);
		endif;
		$new_image = '';
        if(!empty($_POST['image'])):
        $src= base64_decode($_POST['image']);
        $img = 'logo.png'; 
        file_put_contents($img, file_get_contents($src));
        $img_url= get_home_url().'/wp-admin/logo.png';
		$new_image = sanitize_url($img_url);
		endif;
		$format = '';
        if(!empty($_POST['fm'])):
		$format = sanitize_text_field($_POST['fm']);
		$new_image = $new_image.'?fm=.'.$format;
		endif;
		$res = $this->image_buzz_set_image_from_url($new_image);
        if($res > 0):
			$value = wp_get_attachment_url($res);
			$data = array('status' => 'true', 'id'=> $res, 'url'=> $value);
			echo json_encode($data);
		else:
			$data = array('status' => 'false','msg'=>esc_html__('Some Thing Went to Wrong!','image-buzz'));
			echo json_encode($data);
		endif;
        wp_die(); 
	}	
    /**
	 * WP Media Libary In Image File Save
	 */
	public function image_buzz_set_image_from_url($url) {
        $tmp = download_url($url);
	    $file_array = array(
			'name' => basename( $url ),
			'tmp_name' => $tmp
		);
	    if(is_wp_error($tmp)){
			@unlink( $file_array[ 'tmp_name' ] );
			return $tmp;
		}
	    $post_id = '0';
	    $id = media_handle_sideload( $file_array, $post_id );
	    if(is_wp_error($id)){
			@unlink( $file_array['tmp_name']);
			return $id;
		}
	    return $id;
	}
	 /**
	 * image buzz Videos Text Save in Post
     */
	public function image_buzz_videos_saveinpost(){
        $author_id = get_current_user_id();
		$title = '';
		if(isset($_POST['post_title'])):
			$title = sanitize_text_field($_POST['post_title']);
		endif;
		$video_id = '';
		if(isset($_POST['ytc_video_id'])):
			$video_id = sanitize_text_field($_POST['ytc_video_id']);
		endif;
	    $content = '';
	    if(isset($_POST['mycustomeditor'])):
	     $content = sanitize_text_field($_POST['mycustomeditor']);
	    endif;
		$status = '';
	    if(isset($_POST['post_status'])):
	      $status = sanitize_text_field($_POST['post_status']);
	    endif;
        $date = date('Y-m-d H:i:s', time());
		$include_thumbnail = '';
		if(isset($_POST['include_thumbnail'])):
			$include_thumbnail = sanitize_text_field($_POST['include_thumbnail']);
		endif;
	    $include_video_post = '';
	    if(isset($_POST['include_video_post'])):
	     $include_video_post = sanitize_text_field($_POST['include_video_post']);
	    endif;
		$categories = '';
	    if(isset($_POST['post_categories'])):
	     $categories = sanitize_text_field($_POST['post_categories']);
        endif;
		$tags = '';
		if(isset($_POST['post_tags'])):
	     $tags = sanitize_text_field($_POST['post_tags']);
        endif;
		$thumb_image_url = '';
		if(isset($_POST['thumb_image_url'])):
		  $thumb_image_url = sanitize_text_field($_POST['thumb_image_url']);
		endif;
     
		if($include_video_post=='addvideo'):
            $yt_video_content ='<br><iframe src="'.esc_url('https://www.youtube.com/embed/'.esc_attr($video_id)).'" title="'.esc_html($title).'" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe>';
			$content .= $yt_video_content;
		endif;

	    $post_id = wp_insert_post(
				array(
					'comment_status' => 'closed',
					'ping_status' => 'closed',
					'post_author' => $author_id,
					'post_title' => $title,
					'post_content' => $content,
					'post_status' => $status,
					'post_type' => 'post',
					'post_date_gmt' => gmdate('Y-m-d H:i:s', strtotime($date)),
					'post_date' => $date,
					'edit_date' => 'true'
				));
    if($tags){
	  wp_set_post_tags($post_id, $tags, false);
	}
    if($categories){
	  $cat_arr = explode(',', $categories);
	  wp_set_post_categories($post_id, $cat_arr, false);
	}
	if($include_thumbnail == 'addthumbnail'):
		if(!empty($thumb_image_url)):
          $this->image_buzz_generate_featured_image($thumb_image_url, $post_id);
		endif;
	endif;
    if($post_id):
	   echo json_encode(array('status'=>'success','msg'=> esc_html__('Post Created Successfully','image-buzz')));
	else:
	   echo json_encode(array('status'=>'fail','msg'=> esc_html__('Something went wrong','image-buzz')));
	endif;
	wp_die();	
	}
	
	/**
	 * Image Buzz Generate Featured Image
	 */ 
	public function image_buzz_generate_featured_image($image_url, $post_id){
        $upload_dir = wp_upload_dir();
        $image_data = file_get_contents($image_url);
        $filename = basename($image_url);
        if(wp_mkdir_p($upload_dir['path']))
            $file = $upload_dir['path'] . '/' . $post_id . '_' . $filename;
        else
            $file = $upload_dir['basedir'] . '/' . $post_id . '_' . $filename;
        file_put_contents($file, $image_data);
        $wp_filetype = wp_check_filetype($filename, null);
        $attachment = array(
            'post_mime_type' => $wp_filetype['type'],
            'post_title' => sanitize_file_name($filename),
            'post_content' => '',
            'post_status' => 'inherit'
        );
        $attach_id = wp_insert_attachment($attachment, $file, $post_id);
        require_once(ABSPATH . 'wp-admin/includes/image.php');
        $attach_data = wp_generate_attachment_metadata($attach_id, $file);
        $res1 = wp_update_attachment_metadata($attach_id, $attach_data);
        $res2 = set_post_thumbnail($post_id, $attach_id);
    }
    
	
    /**
	 * Image Generator Plugin
	 */
	public function image_buzz_img_generator($attr) {
		$args = shortcode_atts( array(
			'template_id' => '',
		), $attr );
		$ogj = $attr['obj'];
		$num = '';
		if(!empty($attr['num'])){
		    $num = $attr['num'];
		}else{
		    $num = 1;
		}
		if(!empty($attr['size'])){
		    $size = $attr['size'];
		}else{
		    $size = "1024x1024";
		}
		$imagebuzz_openai_api_save = get_option('imagebuzz_openai_api_save');
		ob_start();
		$output = '';
		if(!empty($ogj)){
    		    
    		$args = array(
                "prompt" => $ogj,
                "n"=>3,
                "size"=>$size
            );                                                                
            $data_string = json_encode($args);  
            $ch = curl_init('https://api.openai.com/v1/images/generations');
            curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "POST");                                       
            curl_setopt($ch, CURLOPT_POSTFIELDS, $data_string);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);                         
            curl_setopt($ch, CURLOPT_HTTPHEADER, array(
            'Authorization: Bearer '.$imagebuzz_openai_api_save,
            'Content-Type: application/json'
            ));
            $result = curl_exec($ch);
            $a = json_decode($result,true);
            /* print_r($a);
            die(); */
            if(isset($a['data'])){
                $imgUrl = $a['data'][0]['url'];
                echo '<img src="'.$imgUrl.'">';
            }
            else{
                echo '<p>'.$a['error']['message'].'</p>';
            }
		}
        else{
            echo '<p>Please Enter Object Name.</p>';
        }
		$output = ob_get_clean();
		return $output;
	}
}  